bayespy.utils.misc.CholeskyDense
================================

.. currentmodule:: bayespy.utils.misc

.. autoclass:: CholeskyDense

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~CholeskyDense.__init__
      ~CholeskyDense.logdet
      ~CholeskyDense.solve
      ~CholeskyDense.trace_solve_gradient
   
   

   
   
   